@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2021 Greenbone Networks GmbH
+/* Copyright (C) 2009-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -95,11 +95,13 @@
 #include <gvm/base/pidfile.h>
 #include <gvm/base/pwpolicy.h>
 #include <gvm/base/logging.h>
-#include <gvm/base/proctitle.h>
+#include <bsd/unistd.h>
+#include <gvm/base/gvm_sentry.h>
 #include <gvm/util/fileutils.h>
 #include <gvm/util/serverutils.h>
 #include <gvm/util/ldaputils.h>
 
+#include "debug_utils.h"
 #include "manage.h"
 #include "manage_sql_nvts.h"
 #include "manage_sql_secinfo.h"
@@ -183,6 +185,11 @@
  */
 #define DEFAULT_CLIENT_WATCH_INTERVAL 1
 
+/**
+ * @brief Default broker address
+ */
+#define DEFAULT_BROKER_ADDRESS "localhost:1883"
+
 /**
  * @brief Maximum number of frames in backtrace.
  *
@@ -461,6 +468,7 @@ serve_client (int server_socket, gvm_connection_t *client_connection)
           g_critical ("%s: failed to set SO_KEEPALIVE on scanner socket: %s",
                       __func__,
                       strerror (errno));
+          gvm_close_sentry ();
           exit (EXIT_FAILURE);
         }
     }
@@ -567,6 +575,7 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
       g_critical ("%s: failed to accept client connection: %s",
                   __func__,
                   strerror (errno));
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
   sockaddr_as_str (&addr, client_address);
@@ -588,9 +597,10 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
           struct sigaction action;
           gvm_connection_t client_connection;
 
+          init_sentry ();
           is_parent = 0;
 
-          proctitle_set ("gvmd: Serving client");
+          setproctitle ("gvmd: Serving client");
 
           /* Restore the sigmask that was blanked for pselect. */
           pthread_sigmask (SIG_SETMASK, sigmask_current, NULL);
@@ -605,6 +615,7 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
                           strerror (errno));
               shutdown (client_socket, SHUT_RDWR);
               close (client_socket);
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
             }
 
@@ -618,6 +629,7 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
                           strerror (errno));
               shutdown (client_socket, SHUT_RDWR);
               close (client_socket);
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
             }
           /* Reopen the database (required after fork). */
@@ -628,6 +640,7 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
           client_connection.session = client_session;
           client_connection.credentials = client_credentials;
           ret = serve_client (server_socket, &client_connection);
+          gvm_close_sentry ();
           exit (ret);
         }
       case -1:
@@ -674,6 +687,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
     {
       case 0:
         /* Child. */
+        init_sentry ();
         cleanup_manage_process (FALSE);
         break;
 
@@ -703,6 +717,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
   if (socketpair (AF_UNIX, SOCK_STREAM, 0, sockets))
     {
       g_warning ("%s: socketpair: %s", __func__, strerror (errno));
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
 
@@ -720,7 +735,8 @@ fork_connection_internal (gvm_connection_t *client_connection,
       case 0:
         /* Child.  Serve the scheduler GMP, then exit. */
 
-        proctitle_set ("gvmd: Serving GMP internally");
+        init_sentry ();
+        setproctitle ("gvmd: Serving GMP internally");
 
         parent_client_socket = sockets[0];
 
@@ -734,6 +750,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
                         strerror (errno));
             shutdown (parent_client_socket, SHUT_RDWR);
             close (parent_client_socket);
+            gvm_close_sentry ();
             exit (EXIT_FAILURE);
           }
 
@@ -747,6 +764,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
                         strerror (errno));
             shutdown (parent_client_socket, SHUT_RDWR);
             close (parent_client_socket);
+            gvm_close_sentry ();
             exit (EXIT_FAILURE);
           }
 
@@ -778,6 +796,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
               {
                 g_critical ("%s: client server initialisation failed",
                             __func__);
+                gvm_close_sentry ();
                 exit (EXIT_FAILURE);
               }
             set_gnutls_priority (&client_session, priorities_option);
@@ -798,6 +817,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
         client_connection->credentials = client_credentials;
         ret = serve_client (manager_socket, client_connection);
 
+        gvm_close_sentry ();
         exit (ret);
         break;
 
@@ -805,6 +825,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
         /* Parent when error. */
 
         g_warning ("%s: fork: %s", __func__, strerror (errno));
+        gvm_close_sentry ();
         exit (EXIT_FAILURE);
         break;
 
@@ -813,7 +834,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
 
         g_debug ("%s: %i forked %i", __func__, getpid (), pid);
 
-        proctitle_set ("gvmd: Requesting GMP internally");
+        setproctitle ("gvmd: Requesting GMP internally");
 
         /* This process is returned as the child of
          * fork_connection_for_scheduler so that the returned parent can wait
@@ -845,11 +866,17 @@ fork_connection_internal (gvm_connection_t *client_connection,
                                 CLIENTKEY,
                                 &client_connection->session,
                                 &client_connection->credentials))
-              exit (EXIT_FAILURE);
+              {
+                gvm_close_sentry ();
+                exit (EXIT_FAILURE);
+              }
 
             if (gvm_server_attach (client_connection->socket,
                                    &client_connection->session))
-              exit (EXIT_FAILURE);
+              {
+                gvm_close_sentry ();
+                exit (EXIT_FAILURE);
+              }
           }
 
         g_debug ("%s: all set to request GMP on socket %i",
@@ -859,6 +886,7 @@ fork_connection_internal (gvm_connection_t *client_connection,
         break;
     }
 
+  gvm_close_sentry ();
   exit (EXIT_FAILURE);
   return -1;
 }
@@ -918,8 +946,17 @@ cleanup ()
   /** @todo These should happen via gmp, maybe with "cleanup_gmp ();". */
   cleanup_manage_process (TRUE);
   g_strfreev (disabled_commands);
-  if (manager_socket > -1) close (manager_socket);
-  if (manager_socket_2 > -1) close (manager_socket_2);
+  if (manager_socket > -1)
+    {
+      close (manager_socket);
+      manager_socket = -1;
+    }
+  if (manager_socket_2 > -1)
+    {
+      close (manager_socket_2);
+      manager_socket_2 = -1;
+    }
+
 #if LOG
   if (log_stream != NULL)
     {
@@ -1054,6 +1091,7 @@ handle_sigchld (/* unused */ int given_signal, siginfo_t *info, void *ucontext)
 static void
 handle_sigabrt_simple (int signal)
 {
+  gvm_close_sentry ();
   exit (EXIT_FAILURE);
 }
 
@@ -1067,7 +1105,7 @@ handle_sigabrt_simple (int signal)
 static int
 update_nvt_cache_osp (const gchar *update_socket)
 {
-  proctitle_set ("gvmd: OSP: Updating NVT cache");
+  setproctitle ("gvmd: OSP: Updating NVT cache");
 
   return manage_update_nvts_osp (update_socket);
 }
@@ -1083,7 +1121,7 @@ update_nvt_cache_osp (const gchar *update_socket)
 static int
 update_nvt_cache_retry ()
 {
-  proctitle_set ("gvmd: Reloading NVTs");
+  setproctitle ("gvmd: Reloading NVTs");
 
   /* Don't ignore SIGCHLD, in order to wait for child process. */
   setup_signal_handler (SIGCHLD, SIG_DFL, 0);
@@ -1107,6 +1145,8 @@ update_nvt_cache_retry ()
       else if (child_pid == 0)
         {
           const char *osp_update_socket;
+
+          init_sentry ();
           osp_update_socket = get_osp_vt_update_socket ();
           if (osp_update_socket)
             {
@@ -1123,11 +1163,13 @@ update_nvt_cache_retry ()
                     g_message ("%s: rebuild successful", __func__);
                 }
 
+              gvm_close_sentry ();
               exit (ret);
             }
           else
             {
               g_warning ("%s: No OSP VT update socket set", __func__);
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
             }
         }
@@ -1173,7 +1215,8 @@ fork_update_nvt_cache ()
       case 0:
         /* Child.   */
 
-        proctitle_set ("gvmd: Updating NVT cache");
+        init_sentry ();
+        setproctitle ("gvmd: Updating NVT cache");
 
         /* Clean up the process. */
 
@@ -1183,8 +1226,16 @@ fork_update_nvt_cache ()
           pthread_sigmask (SIG_SETMASK, &sigmask_current, NULL);
         /** @todo This should happen via gmp, maybe with "cleanup_gmp ();". */
         cleanup_manage_process (FALSE);
-        if (manager_socket > -1) close (manager_socket);
-        if (manager_socket_2 > -1) close (manager_socket_2);
+        if (manager_socket > -1)
+          {
+            close (manager_socket);
+            manager_socket = -1;
+          }
+        if (manager_socket_2 > -1)
+          {
+            close (manager_socket_2);
+            manager_socket_2 = -1;
+          }
 
         /* Update the cache. */
 
@@ -1193,6 +1244,7 @@ fork_update_nvt_cache ()
         /* Exit. */
 
         cleanup_manage_process (FALSE);
+        gvm_close_sentry ();
         exit (EXIT_SUCCESS);
 
         break;
@@ -1274,7 +1326,8 @@ fork_feed_sync ()
       case 0:
         /* Child.   */
 
-        proctitle_set ("gvmd: Synchronizing feed data");
+        init_sentry ();
+        setproctitle ("gvmd: Synchronizing feed data");
 
         /* Clean up the process. */
 
@@ -1284,8 +1337,16 @@ fork_feed_sync ()
           pthread_sigmask (SIG_SETMASK, &sigmask_current, NULL);
         /** @todo This should happen via gmp, maybe with "cleanup_gmp ();". */
         cleanup_manage_process (FALSE);
-        if (manager_socket > -1) close (manager_socket);
-        if (manager_socket_2 > -1) close (manager_socket_2);
+        if (manager_socket > -1)
+          {
+            close (manager_socket);
+            manager_socket = -1;
+          }
+        if (manager_socket_2 > -1)
+          {
+            close (manager_socket_2);
+            manager_socket_2 = -1;
+          }
 
         /* Check the feed version. */
 
@@ -1295,6 +1356,7 @@ fork_feed_sync ()
         /* Exit. */
 
         cleanup_manage_process (FALSE);
+        gvm_close_sentry ();
         exit (EXIT_SUCCESS);
 
         break;
@@ -1338,11 +1400,13 @@ serve_and_schedule ()
   if (sigfillset (&sigmask_all))
     {
       g_critical ("%s: Error filling signal set", __func__);
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
   if (pthread_sigmask (SIG_BLOCK, &sigmask_all, &sigmask_current))
     {
       g_critical ("%s: Error setting signal mask", __func__);
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
   sigmask_normal = &sigmask_current;
@@ -1389,6 +1453,7 @@ serve_and_schedule ()
             case 1:
               break;
             default:
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
           }
 
@@ -1411,6 +1476,7 @@ serve_and_schedule ()
           g_critical ("%s: select failed: %s",
                       __func__,
                       strerror (errno));
+          gvm_close_sentry ();
           exit (EXIT_FAILURE);
         }
 
@@ -1420,11 +1486,13 @@ serve_and_schedule ()
           if (FD_ISSET (manager_socket, &exceptfds))
             {
               g_critical ("%s: exception in select", __func__);
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
             }
           if ((manager_socket_2 > -1) && FD_ISSET (manager_socket_2, &exceptfds))
             {
               g_critical ("%s: exception in select (2)", __func__);
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
             }
           if (FD_ISSET (manager_socket, &readfds))
@@ -1445,6 +1513,7 @@ serve_and_schedule ()
             case 1:
               break;
             default:
+              gvm_close_sentry ();
               exit (EXIT_FAILURE);
           }
 
@@ -1749,7 +1818,7 @@ parse_authentication_goption_arg (const gchar *opt, const gchar *arg,
  * @return EXIT_SUCCESS on success, EXIT_FAILURE on failure.
  */
 int
-gvmd (int argc, char** argv)
+gvmd (int argc, char** argv, char *env[])
 {
   /* Process options. */
 
@@ -1813,15 +1882,24 @@ gvmd (int argc, char** argv)
   static gchar *role = NULL;
   static gchar *disable = NULL;
   static gchar *value = NULL;
+  static gchar *broker_address = NULL;
   static gchar *feed_lock_path = NULL;
   static int feed_lock_timeout = 0;
   static gchar *vt_verification_collation = NULL;
 
+  GString *full_disable_commands = g_string_new ("");
+
+  int sentry_initialized;
   GError *error = NULL;
   lockfile_t lockfile_checking, lockfile_serving;
   GOptionContext *option_context;
   static GOptionEntry option_entries[]
     = {
+        { "broker-address", '\0', 0, G_OPTION_ARG_STRING,
+          &broker_address,
+          "Sets the address for the publish-subscribe message (MQTT) broker."
+          " Defaults to " DEFAULT_BROKER_ADDRESS ". Set to empty to disable.",
+          "<address>" },
         { "check-alerts", '\0', 0, G_OPTION_ARG_NONE,
           &check_alerts,
           "Check SecInfo alerts.",
@@ -1994,7 +2072,7 @@ gvmd (int argc, char** argv)
           " cleanup-config-prefs, cleanup-feed-permissions,"
           " cleanup-port-names, cleanup-report-formats, cleanup-result-encoding,"
           " cleanup-result-nvts, cleanup-result-severities,"
-          " cleanup-schedule-times, migrate-relay-sensors,"
+          " cleanup-schedule-times, cleanup-sequences, migrate-relay-sensors,"
           " rebuild-report-cache or update-report-cache.",
           "<name>" },
         { "osp-vt-update", '\0', 0, G_OPTION_ARG_STRING,
@@ -2152,6 +2230,7 @@ gvmd (int argc, char** argv)
     }
   g_option_context_free (option_context);
 
+  sentry_initialized = init_sentry ();
   if (print_version)
     {
       printf ("Greenbone Vulnerability Manager %s\n", GVMD_VERSION);
@@ -2159,11 +2238,24 @@ gvmd (int argc, char** argv)
       printf ("GIT revision %s\n", GVMD_GIT_REVISION);
 #endif
       printf ("Manager DB revision %i\n", manage_db_supported_version ());
+      if (gvm_has_sentry_support ())
+        {
+          const char *sentry_dsn;
+          sentry_dsn = g_getenv ("SENTRY_DSN_GVMD");
+
+          if (sentry_initialized)
+            printf ("Sentry support enabled with DSN %s\n", sentry_dsn);
+          else if (sentry_dsn == NULL)
+            printf ("Sentry support disabled: no DSN set\n");
+          else
+            printf ("Sentry support disabled\n");
+        }
       printf ("Copyright (C) 2009-2021 Greenbone Networks GmbH\n");
       printf ("License: AGPL-3.0-or-later\n");
       printf
         ("This is free software: you are free to change and redistribute it.\n"
          "There is NO WARRANTY, to the extent permitted by law.\n\n");
+      gvm_close_sentry ();
       exit (EXIT_SUCCESS);
     }
 
@@ -2174,6 +2266,11 @@ gvmd (int argc, char** argv)
       client_watch_interval = 0;
     }
 
+  /* Set broker address */
+  set_broker_address (broker_address
+                        ? broker_address
+                        : DEFAULT_BROKER_ADDRESS);
+
   /* Set feed lock path */
   set_feed_lock_path (feed_lock_path);
   
@@ -2229,8 +2326,8 @@ gvmd (int argc, char** argv)
 
   /* Set process title. */
 
-  proctitle_init (argc, argv);
-  proctitle_set ("gvmd: Initializing");
+  setproctitle_init (argc, argv, env);
+  setproctitle ("gvmd: Initializing");
 
   /* Setup initial signal handlers. */
 
@@ -2244,6 +2341,7 @@ gvmd (int argc, char** argv)
   else if (setenv ("TZ", "utc 0", 1) == -1)
     {
       g_critical ("%s: failed to set timezone", __func__);
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
   tzset ();
@@ -2261,6 +2359,18 @@ gvmd (int argc, char** argv)
     log_config = load_log_configuration (rc_name);
   g_free (rc_name);
   setup_log_handlers (log_config);
+
+  /* Log whether sentry support is enabled */
+  if (sentry_initialized)
+    {
+      g_message ("Sentry support enabled with DSN %s",
+                 g_getenv ("SENTRY_DSN_GVMD"));
+    }
+  else
+    {
+      g_debug ("Sentry support disabled");
+    }
+
   /* Enable GNUTLS debugging if requested via env variable.  */
   {
     const char *s;
@@ -2401,7 +2511,7 @@ gvmd (int argc, char** argv)
           return EXIT_FAILURE;
         }
 
-      proctitle_set ("gvmd: Migrating database");
+      setproctitle ("gvmd: Migrating database");
 
       g_info ("   Migrating database.");
 
@@ -2486,7 +2596,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Optimizing");
+      setproctitle ("gvmd: Optimizing");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2502,7 +2612,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: --rebuild");
+      setproctitle ("gvmd: --rebuild");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2524,7 +2634,7 @@ gvmd (int argc, char** argv)
       
       error_msg = NULL;
 
-      proctitle_set ("gvmd: --rebuild-gvmd-data");
+      setproctitle ("gvmd: --rebuild-gvmd-data");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2549,7 +2659,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: --rebuild-scap");
+      setproctitle ("gvmd: --rebuild-scap");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2568,7 +2678,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: --dump-vt-verification");
+      setproctitle ("gvmd: --dump-vt-verification");
   
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2591,7 +2701,7 @@ gvmd (int argc, char** argv)
 
       /* Create the scanner and then exit. */
 
-      proctitle_set ("gvmd: Creating scanner");
+      setproctitle ("gvmd: Creating scanner");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2612,8 +2722,6 @@ gvmd (int argc, char** argv)
 
       if (!scanner_type || !strcasecmp (scanner_type, "OpenVAS"))
         type = SCANNER_TYPE_OPENVAS;
-      else if (!strcasecmp (scanner_type, "OSP"))
-        type = SCANNER_TYPE_OSP;
       else if (!strcasecmp (scanner_type, "OSP-Sensor"))
         type = SCANNER_TYPE_OSP_SENSOR;
       else
@@ -2645,7 +2753,7 @@ gvmd (int argc, char** argv)
 
       /* Modify the scanner and then exit. */
 
-      proctitle_set ("gvmd: Modifying scanner");
+      setproctitle ("gvmd: Modifying scanner");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2656,8 +2764,6 @@ gvmd (int argc, char** argv)
 
           if (strcasecmp (scanner_type, "OpenVAS") == 0)
             type = SCANNER_TYPE_OPENVAS;
-          else if (strcasecmp (scanner_type, "OSP") == 0)
-            type = SCANNER_TYPE_OSP;
           else if (!strcasecmp (scanner_type, "OSP-Sensor"))
             type = SCANNER_TYPE_OSP_SENSOR;
           else
@@ -2691,7 +2797,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Checking alerts");
+      setproctitle ("gvmd: Checking alerts");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2707,7 +2813,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Creating user");
+      setproctitle ("gvmd: Creating user");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2724,7 +2830,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Deleting user");
+      setproctitle ("gvmd: Deleting user");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2740,7 +2846,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Getting roles");
+      setproctitle ("gvmd: Getting roles");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2756,7 +2862,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Getting users");
+      setproctitle ("gvmd: Getting users");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2772,7 +2878,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Getting scanners");
+      setproctitle ("gvmd: Getting scanners");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2788,7 +2894,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Deleting scanner");
+      setproctitle ("gvmd: Deleting scanner");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2804,7 +2910,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Verifying scanner");
+      setproctitle ("gvmd: Verifying scanner");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2820,7 +2926,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Modifying user password");
+      setproctitle ("gvmd: Modifying user password");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2836,7 +2942,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Modifying setting");
+      setproctitle ("gvmd: Modifying setting");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2853,7 +2959,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Encrypting all credentials");
+      setproctitle ("gvmd: Encrypting all credentials");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2869,7 +2975,7 @@ gvmd (int argc, char** argv)
     {
       int ret;
 
-      proctitle_set ("gvmd: Decrypting all credentials");
+      setproctitle ("gvmd: Decrypting all credentials");
 
       if (option_lock (&lockfile_checking))
         return EXIT_FAILURE;
@@ -2910,6 +3016,7 @@ gvmd (int argc, char** argv)
         {
           case 0:
             /* Child. */
+            init_sentry ();
             break;
           case -1:
             /* Parent when error. */
@@ -2917,11 +3024,13 @@ gvmd (int argc, char** argv)
                         __func__,
                         strerror (errno));
             log_config_free ();
+            gvm_close_sentry ();
             exit (EXIT_FAILURE);
             break;
           default:
             /* Parent. */
             log_config_free ();
+            gvm_close_sentry ();
             exit (EXIT_SUCCESS);
             break;
         }
@@ -2939,6 +3048,7 @@ gvmd (int argc, char** argv)
       case -2:
         g_critical ("%s: database is wrong version", __func__);
         log_config_free ();
+        gvm_close_sentry ();
         exit (EXIT_FAILURE);
         break;
       case -4:
@@ -2948,12 +3058,14 @@ gvmd (int argc, char** argv)
                     MANAGE_ABSOLUTE_MAX_IPS_PER_TARGET,
                     max_ips_per_target);
         log_config_free ();
+        gvm_close_sentry ();
         exit (EXIT_FAILURE);
         break;
       case -1:
       default:
         g_critical ("%s: failed to initialise GMP daemon", __func__);
         log_config_free ();
+        gvm_close_sentry ();
         exit (EXIT_FAILURE);
     }
 
@@ -2962,6 +3074,7 @@ gvmd (int argc, char** argv)
   if (lockfile_unlock (&lockfile_checking))
     {
       g_critical ("%s: Error releasing checking lock", __func__);
+      gvm_close_sentry ();
       return EXIT_FAILURE;
     }
 
@@ -2972,17 +3085,33 @@ gvmd (int argc, char** argv)
       g_critical ("%s: failed to register `atexit' cleanup function",
                   __func__);
       log_config_free ();
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
 
   /* Set our pidfile. */
 
-  if (pidfile_create (GVMD_PID_PATH)) exit (EXIT_FAILURE);
+  if (pidfile_create (GVMD_PID_PATH))
+    {
+      gvm_close_sentry ();
+      exit (EXIT_FAILURE);
+    }
 
   /* Setup global variables. */
 
   if (disable)
-    disabled_commands = g_strsplit (disable, ",", 0);
+    g_string_append (full_disable_commands, disable);
+
+#ifndef HAS_LIBTHEIA
+  if (full_disable_commands->len)
+    g_string_append_c (full_disable_commands, ',');
+  g_string_append (full_disable_commands, "get_license,modify_license");
+#endif
+
+  if (full_disable_commands->len)
+    disabled_commands = g_strsplit (full_disable_commands->str, ",", 0);
+
+  g_string_free(full_disable_commands, TRUE);
 
   scheduling_enabled = (disable_scheduling == FALSE);
 
@@ -2998,6 +3127,7 @@ gvmd (int argc, char** argv)
       g_critical ("%s: failed to create log directory: %s",
                   __func__,
                   strerror (errno));
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
 
@@ -3007,6 +3137,7 @@ gvmd (int argc, char** argv)
       g_critical ("%s: failed to open log file: %s",
                   __func__,
                   strerror (errno));
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
 #endif
@@ -3034,6 +3165,7 @@ gvmd (int argc, char** argv)
         {
           g_critical ("%s: client server initialisation failed",
                       __func__);
+          gvm_close_sentry ();
           exit (EXIT_FAILURE);
         }
       priorities_option = priorities;
@@ -3077,7 +3209,10 @@ gvmd (int argc, char** argv)
 
   // TODO Should be part of manage init.
   if (gvm_auth_init ())
-    exit (EXIT_FAILURE);
+    {
+      gvm_close_sentry ();
+      exit (EXIT_FAILURE);
+    }
 
   if (check_osp_vt_update_socket ())
     {
@@ -3085,13 +3220,15 @@ gvmd (int argc, char** argv)
                   " Use --osp-vt-update or change the 'OpenVAS Default'"
                   " scanner to use the main ospd-openvas socket.",
                   __func__);
+      gvm_close_sentry ();
       exit (EXIT_FAILURE);
     }
 
   /* Enter the main forever-loop. */
 
-  proctitle_set ("gvmd: Waiting for incoming connections");
+  setproctitle ("gvmd: Waiting for incoming connections");
   serve_and_schedule ();
 
+  gvm_close_sentry ();
   return EXIT_SUCCESS;
 }
