@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2020 Greenbone Networks GmbH
+/* Copyright (C) 2009-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -25,6 +25,6 @@
 #define _GVMD_H
 
 int
-gvmd (int, char **);
+gvmd (int, char **, char **);
 
 #endif /* not _GVMD_H */
