@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2021 Greenbone Networks GmbH
+/* Copyright (C) 2013-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -2206,7 +2206,6 @@ migrate_232_to_233_set_predefined (const gchar *type, const gchar *table)
   gchar *dir_path;
 
   dir_path = g_build_filename (GVMD_FEED_DIR,
-                               GMP_VERSION_FEED,
                                type,
                                NULL);
 
@@ -2289,13 +2288,13 @@ migrate_232_to_233 ()
        " WHERE id IN (SELECT resource FROM resources_predefined"
        "              WHERE resource_type = 'report_format');");
 
-  migrate_232_to_233_set_predefined ("report_formats", "report_formats");
-  migrate_232_to_233_set_predefined ("configs", "configs");
-  migrate_232_to_233_set_predefined ("port_lists", "port_lists");
+  migrate_232_to_233_set_predefined ("report-formats", "report_formats");
+  migrate_232_to_233_set_predefined ("scan-configs", "configs");
+  migrate_232_to_233_set_predefined ("port-lists", "port_lists");
 
-  migrate_232_to_233_set_predefined ("report_formats", "report_formats_trash");
-  migrate_232_to_233_set_predefined ("configs", "configs_trash");
-  migrate_232_to_233_set_predefined ("port_lists", "port_lists_trash");
+  migrate_232_to_233_set_predefined ("report-formats", "report_formats_trash");
+  migrate_232_to_233_set_predefined ("scan-configs", "configs_trash");
+  migrate_232_to_233_set_predefined ("port-lists", "port_lists_trash");
 
   sql ("DROP TABLE resources_predefined;");
 
@@ -2651,6 +2650,298 @@ migrate_241_to_242 ()
   return 0;
 }
 
+/**
+ * @brief Migrate the database from version 242 to version 243.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_242_to_243 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 242. */
+
+  if (manage_db_version () != 242)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE reports DROP COLUMN source_iface;");
+
+  /* Set the database version to 243. */
+
+  set_db_version (243);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 243 to version 244.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_243_to_244 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 243. */
+
+  if (manage_db_version () != 243)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE reports ADD COLUMN modification_time integer;");
+  sql ("UPDATE reports SET modification_time = end_time;");
+
+  /* Set the database version to 244. */
+
+  set_db_version (244);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 244 to version 245.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_244_to_245 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 244. */
+
+  if (manage_db_version () != 244)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE reports RENAME COLUMN date TO creation_time;");
+
+  /* Set the database version to 245. */
+
+  set_db_version (245);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 245 to version 246.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_245_to_246 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 245. */
+
+  if (manage_db_version () != 245)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  /* The support of Business Process Maps has been discontinued. Therefore
+   * any entry in the settings table where "Business Process Map" data are
+   * stored can be deleted
+   */
+
+  /* Delete any setting for "Business Process Maps" . */
+  sql ("DELETE FROM settings WHERE uuid = '3232d608-e5bb-415e-99aa-019f16eede8d';");
+  sql ("DELETE FROM settings WHERE uuid = '3ce2d136-bb52-448a-93f0-20069566f877';");
+
+  /* Set the database version to 246. */
+
+  set_db_version (246);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 246 to version 247.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_246_to_247 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 246. */
+
+  if (manage_db_version () != 246)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  /* Per-user limitations on network interfaces have been removed */
+  sql ("ALTER TABLE users DROP COLUMN ifaces;");
+  sql ("ALTER TABLE users DROP COLUMN ifaces_allow;");
+
+  /* Set the database version to 247. */
+
+  set_db_version (247);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 247 to version 248.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_247_to_248 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 247. */
+
+  if (manage_db_version () != 247)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  /* OSP-scanners are no longer supported. So delete the
+   * the column hr_name, which was only used by OSP-scanners.
+   */
+  sql ("ALTER TABLE config_preferences DROP COLUMN hr_name;");
+  sql ("ALTER TABLE config_preferences_trash DROP COLUMN hr_name;");
+
+  /* Set the database version to 248. */
+
+  set_db_version (248);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 248 to version 249.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_248_to_249 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 248. */
+
+  if (manage_db_version () != 248)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  /* Remove config data for OSP-Scanners */
+  sql ("DELETE FROM config_preferences_trash WHERE config IN"
+       " (SELECT id FROM configs_trash WHERE type = 1);");
+  sql ("DELETE FROM configs_trash WHERE type = 1;");
+  sql ("ALTER TABLE configs_trash DROP COLUMN scanner;");
+  sql ("ALTER TABLE configs_trash DROP COLUMN type;");
+
+  sql ("DELETE FROM config_preferences WHERE config IN"
+       " (SELECT id FROM configs WHERE type = 1);");
+  sql ("DELETE FROM configs WHERE type = 1;");
+  sql ("ALTER TABLE configs DROP COLUMN scanner;");
+  sql ("ALTER TABLE configs DROP COLUMN type;");
+
+  /* Set the database version to 249. */
+
+  set_db_version (249);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 249 to version 250.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_249_to_250 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 249. */
+
+  if (manage_db_version () != 249)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  /* Disable the "table_based_lsc" scanner preference for all policies */
+  sql ("INSERT INTO config_preferences (config, type, name, value)"
+       " SELECT id, 'SERVER_PREFS', 'table_driven_lsc', '0'"
+       "    FROM configs"
+       "   WHERE usage_type='policy'"
+       "     AND configs.id NOT IN"
+       "          (SELECT config FROM config_preferences"
+       "           WHERE name = 'table_driven_lsc'"
+       "           AND type = 'SERVER_PREFS');");
+
+  /* Disable the "table_based_lsc" scanner preference for all policies 
+   * in the trashcan. */
+  sql ("INSERT INTO config_preferences_trash (config, type, name, value)"
+       " SELECT id, 'SERVER_PREFS', 'table_driven_lsc', '0'"
+       "    FROM configs_trash"
+       "   WHERE usage_type='policy'"
+       "     AND configs_trash.id NOT IN"
+       "          (SELECT config FROM config_preferences_trash"
+       "           WHERE name = 'table_driven_lsc'"
+       "           AND type = 'SERVER_PREFS');");
+  
+  /* Set the database version to 250. */
+
+  set_db_version (250);
+
+  sql_commit ();
+
+  return 0;
+}
+
 #undef UPDATE_DASHBOARD_SETTINGS
 
 /**
@@ -2699,6 +2990,14 @@ static migrator_t database_migrators[] = {
   {240, migrate_239_to_240},
   {241, migrate_240_to_241},
   {242, migrate_241_to_242},
+  {243, migrate_242_to_243},
+  {244, migrate_243_to_244},
+  {245, migrate_244_to_245},
+  {246, migrate_245_to_246},
+  {247, migrate_246_to_247},
+  {248, migrate_247_to_248},
+  {249, migrate_248_to_249},
+  {250, migrate_249_to_250},
   /* End marker. */
   {-1, NULL}};
 
