@@ -1,4 +1,4 @@
-/* Copyright (C) 2019-2020 Greenbone Networks GmbH
+/* Copyright (C) 2019-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -26,7 +26,7 @@
  */
 #define CONFIG_ITERATOR_FILTER_COLUMNS                                        \
  { GET_ITERATOR_FILTER_COLUMNS, "nvt_selector", "families_total",             \
-   "nvts_total", "families_trend", "nvts_trend", "type", "usage_type",        \
+   "nvts_total", "families_trend", "nvts_trend", "usage_type",                \
    "predefined", NULL }
 
 /**
@@ -40,8 +40,6 @@
    { "nvt_count", "nvts_total", KEYWORD_TYPE_INTEGER},                        \
    { "families_growing", "families_trend", KEYWORD_TYPE_INTEGER},             \
    { "nvts_growing", "nvts_trend", KEYWORD_TYPE_INTEGER },                    \
-   { "type", NULL, KEYWORD_TYPE_INTEGER },                                    \
-   { "scanner", NULL, KEYWORD_TYPE_INTEGER },                                 \
    { "0", NULL, KEYWORD_TYPE_INTEGER },                                       \
    { "usage_type", NULL, KEYWORD_TYPE_STRING },                               \
    { "predefined", NULL, KEYWORD_TYPE_INTEGER },                              \
@@ -59,8 +57,6 @@
    { "nvt_count", "nvts_total", KEYWORD_TYPE_INTEGER},                        \
    { "families_growing", "families_trend", KEYWORD_TYPE_INTEGER},             \
    { "nvts_growing", "nvts_trend", KEYWORD_TYPE_INTEGER },                    \
-   { "type", NULL, KEYWORD_TYPE_INTEGER },                                    \
-   { "scanner", NULL, KEYWORD_TYPE_INTEGER },                                 \
    { "scanner_location", NULL, KEYWORD_TYPE_INTEGER },                        \
    { "usage_type", NULL, KEYWORD_TYPE_STRING },                               \
    { "predefined", NULL, KEYWORD_TYPE_INTEGER },                              \
@@ -73,7 +69,7 @@ configs_extra_where (const char *);
 int
 create_config_no_acl (const char *, const char *, int, const char *,
                       int, const array_t *, const array_t *, const char *,
-                      const char *, config_t *, char **);
+                      config_t *, char **);
 
 gboolean
 find_config_no_acl (const char *, config_t *);
@@ -95,7 +91,7 @@ config_updated_in_feed (config_t, const gchar *);
 
 void
 update_config (config_t, const gchar *, const gchar *, const gchar *,
-               const gchar *, int, const array_t*, const array_t*);
+               int, const array_t*, const array_t*);
 
 void
 check_db_configs ();
