@@ -1,4 +1,4 @@
-/* Copyright (C) 2014-2020 Greenbone Networks GmbH
+/* Copyright (C) 2014-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -311,7 +311,6 @@ valid_db_resource_type (const char* type)
          || (strcasecmp (type, "os") == 0)
          || (strcasecmp (type, "note") == 0)
          || (strcasecmp (type, "nvt") == 0)
-         || (strcasecmp (type, "ovaldef") == 0)
          || (strcasecmp (type, "override") == 0)
          || (strcasecmp (type, "port_list") == 0)
          || (strcasecmp (type, "permission") == 0)
@@ -1149,7 +1148,7 @@ icalendar_next_time_from_recurrence (struct icalrecurrencetype recurrence,
       /* Iterate over rule-based recurrences up to first time after
        * reference time */
       while (icaltime_is_null_time (recur_time) == FALSE
-             && icaltime_compare (recur_time, reference_time) < 0)
+             && icaltime_compare (recur_time, reference_time) <= 0)
         {
           if (icalendar_time_matches_array (recur_time, exdates) == FALSE)
             prev_time = recur_time;
@@ -1200,8 +1199,10 @@ icalendar_next_time_from_recurrence (struct icalrecurrencetype recurrence,
  * @brief  Get the next or previous due time from a VCALENDAR component.
  * The VCALENDAR must have simplified with icalendar_from_string for this to
  *  work reliably.
+ * The reference time is usually the current time.
  *
  * @param[in]  vcalendar       The VCALENDAR component to get the time from.
+ * @param[in]  reference_time  The reference time for calculating the next time.
  * @param[in]  default_tzid    Timezone id to use if none is set in the iCal.
  * @param[in]  periods_offset  0 for next, -1 for previous from/before now.
  *
@@ -1209,11 +1210,12 @@ icalendar_next_time_from_recurrence (struct icalrecurrencetype recurrence,
  */
 time_t
 icalendar_next_time_from_vcalendar (icalcomponent *vcalendar,
+                                    time_t reference_time,
                                     const char *default_tzid,
                                     int periods_offset)
 {
   icalcomponent *vevent;
-  icaltimetype dtstart, dtstart_with_tz, ical_now;
+  icaltimetype dtstart, dtstart_with_tz, ical_reference_time;
   icaltimezone *tz;
   icalproperty *rrule_prop;
   struct icalrecurrencetype recurrence;
@@ -1254,12 +1256,12 @@ icalendar_next_time_from_vcalendar (icalcomponent *vcalendar,
   icaltime_set_timezone (&dtstart_with_tz, tz);
 
   // Get current time
-  ical_now = icaltime_current_time_with_zone (tz);
+  ical_reference_time = icaltime_from_timet_with_zone (reference_time, 0, tz);
   // Set timezone explicitly because icaltime_current_time_with_zone doesn't.
-  icaltime_set_timezone (&ical_now, tz);
-  if (ical_now.zone == NULL)
+  icaltime_set_timezone (&ical_reference_time, tz);
+  if (ical_reference_time.zone == NULL)
     {
-      ical_now.zone = tz;
+      ical_reference_time.zone = tz;
     }
 
   // Get EXDATEs and RDATEs
@@ -1276,7 +1278,7 @@ icalendar_next_time_from_vcalendar (icalcomponent *vcalendar,
   // Calculate next time.
   next_time = icalendar_next_time_from_recurrence (recurrence,
                                                    dtstart_with_tz,
-                                                   ical_now, tz,
+                                                   ical_reference_time, tz,
                                                    exdates, rdates,
                                                    periods_offset);
 
@@ -1291,8 +1293,10 @@ icalendar_next_time_from_vcalendar (icalcomponent *vcalendar,
  * @brief  Get the next or previous due time from a VCALENDAR string.
  * The string must be a VCALENDAR simplified with icalendar_from_string for
  *  this to work reliably.
+ * The reference time is usually the current time.
  *
  * @param[in]  ical_string     The VCALENDAR string to get the time from.
+ * @param[in]  reference_time  The reference time for calculating the next time.
  * @param[in]  default_tzid    Timezone id to use if none is set in the iCal.
  * @param[in]  periods_offset  0 for next, -1 for previous from/before now.
  *
@@ -1300,6 +1304,7 @@ icalendar_next_time_from_vcalendar (icalcomponent *vcalendar,
  */
 time_t
 icalendar_next_time_from_string (const char *ical_string,
+                                 time_t reference_time,
                                  const char *default_tzid,
                                  int periods_offset)
 {
@@ -1307,7 +1312,9 @@ icalendar_next_time_from_string (const char *ical_string,
   icalcomponent *ical_parsed;
 
   ical_parsed = icalcomponent_new_from_string (ical_string);
-  next_time = icalendar_next_time_from_vcalendar (ical_parsed, default_tzid,
+  next_time = icalendar_next_time_from_vcalendar (ical_parsed,
+                                                  reference_time,
+                                                  default_tzid,
                                                   periods_offset);
   icalcomponent_free (ical_parsed);
   return next_time;
